package com.sun.jmx.mbeanserver;

import javax.management.Descriptor;
import javax.management.JMX;
import java.lang.ref.WeakReference;
import javax.management.ImmutableDescriptor;
import java.util.WeakHashMap;

public class DescriptorCache
{
    private static final DescriptorCache instance;
    private final WeakHashMap<ImmutableDescriptor, WeakReference<ImmutableDescriptor>> map;
    
    private DescriptorCache() {
        this.map = new WeakHashMap();
    }
    
    static DescriptorCache getInstance() {
        return DescriptorCache.instance;
    }
    
    public static DescriptorCache getInstance(JMX jmx) {
        if (jmx != null) {
            return DescriptorCache.instance;
        }
        return null;
    }
    
    public ImmutableDescriptor get(ImmutableDescriptor referent) {
        WeakReference<Object> weakReference = (WeakReference)this.map.get(referent);
        ImmutableDescriptor immutableDescriptor = (weakReference == null) ? null : ((ImmutableDescriptor)weakReference.get());
        if (immutableDescriptor != null) {
            return immutableDescriptor;
        }
        this.map.put(referent, new WeakReference(referent));
        return referent;
    }
    
    public ImmutableDescriptor union(Descriptor... descriptors) {
        return this.get(ImmutableDescriptor.union(descriptors));
    }
    
    static {
        instance = new DescriptorCache();
    }
}
